@@ -386,7 +386,7 @@ export dsuffix options
 if [ -z "$FRONT_END" ] ; then
    FRONT_END=c
    test "ON" = "ON" && FRONT_END="$FRONT_END cxx"
-   test "OFF" = "ON"    && FRONT_END="$FRONT_END fortran"
+   test "ON" = "ON"    && FRONT_END="$FRONT_END fortran"
    test "OFF" = "ON"   && FRONT_END="$FRONT_END java"
    test "OFF" = "ON" && FRONT_END="$FRONT_END octave"
    test "OFF" = "ON" && FRONT_END="$FRONT_END python"
